@@ -49,8 +49,6 @@ EOF
     my ($code, $tail) = $line =~ /$CODE_RX/;
     defined ($code) ||
         throw Error::Simple ('ERROR: InfoSys::FreeDB::Response::Query::new_from_content_ref, first line of specified \'content_ref\' does not contain a code.');
-    $code == 200 || $code == 211 || $code == 202 || $code == 210 || $code == 403 || $code == 409 ||
-        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Query::new_from_content_ref, first line of specified 'content_ref' does not contain a valid code ($code).");
     my %opt;
     if ($code == 200) {
         my @tail = split(/\s+/, $tail, 3);
@@ -123,7 +121,7 @@ EOF
         );
     }
     else {
-        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Query::new_from_content_ref, unknown code '$code' returned.");
+        throw Error::Simple ("ERROR: InfoSys::FreeDB::Response::Query::new_from_content_ref, unknown code '$code' returned. Allowed codes are 200, 210, 211, 202, 403 and 409.");
     }
 
     # Create a new object and return it
